@@ -6,9 +6,9 @@ def waiting_for(dag_id, parent_dag_ids, timeout=600, allowed_states=['success'],
     tasks = []
     for parent_id in parent_dag_ids:
         tasks.append(ExternalTaskSensor(
-            task_id=f"{parent_id}.{dag_id}.dependency",
+            task_id=f"link.{parent_id}.{dag_id}",
             external_dag_id=parent_id,
-            external_task_id=f"{parent_id}.{dag_id}.dependence",
+            external_task_id=f"link.{parent_id}.{dag_id}",
             timeout=timeout,
             allowed_states=allowed_states,
             failed_states=failed_states,
@@ -21,8 +21,8 @@ def awaited_by(dag_id, child_dag_ids):
     tasks = []
     for child_id in child_dag_ids:
         tasks.append(ExternalTaskMarker(
-            task_id=f"{dag_id}.{child_id}.dependency",
+            task_id=f"link.{dag_id}.{child_id}",
             external_dag_id=child_id,
-            external_task_id=f"{dag_id}.{child_id}.dependency",
+            external_task_id=f"link.{dag_id}.{child_id}",
         ))
     return tasks
